==> members-facade-2.4.1-20221010.073805-5-sources.jar: com/bizvane/members/facade/models/po/MbrIntegralBatchRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrIntegralBatchRecordPO implements Serializable {

	/**
	 * 只读. 批量调整积分记录表pk. mbr_integral_batch_record
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量调整积分记录表pk", name = "mbrIntegralBatchRecord", required = false, example = "")
	private Long mbrIntegralBatchRecord;
	/**
	 * 只读. 公司id. sys_company_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 批次号. batch_no
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批次号", name = "batchNo", required = false, example = "")
	private String batchNo;
	/**
	 * 只读. 会员名称. member_name
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员名称", name = "memberName", required = false, example = "")
	private String memberName;
	/**
	 * 只读. 会员手机号. member_phone
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员手机号", name = "memberPhone", required = false, example = "")
	private String memberPhone;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 会员erpid. erp_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员erpid", name = "erpId", required = false, example = "")
	private String erpId;
	/**
	 * 只读. 积分调整类型 1减少 2增加. change_type
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分调整类型 1减少 2增加", name = "changeType", required = false, example = "")
	private Integer changeType;
	/**
	 * 只读. 业务调整类型 4手动调整支出 5手动调整获取. business_type
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "业务调整类型 4手动调整支出 5手动调整获取", name = "businessType", required = false, example = "")
	private Integer businessType;
	/**
	 * 只读. 更改时间. change_time
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "更改时间", name = "changeTime", required = false, example = "")
	private Date changeTime;
	/**
	 * 只读. 变更积分. change_integral
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更积分", name = "changeIntegral", required = false, example = "")
	private Integer changeIntegral;
	/**
	 * 只读. 变更后积分. count_integral
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更后积分", name = "countIntegral", required = false, example = "")
	private Integer countIntegral;
	/**
	 * 只读. 积分变更状态 0处理中 1处理成功 2处理失败. change_status
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分变更状态 0处理中 1处理成功 2处理失败", name = "changeStatus", required = false, example = "")
	private Integer changeStatus;
	/**
	 * 只读. 积分调整结果. reason
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分调整结果", name = "reason", required = false, example = "")
	private String reason;
	/**
	 * 只读. 操作人id. create_user_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 操作人名称. create_user_name
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 操作日期. create_date
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 1有效 0无效. valid
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1有效 0无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getMbrIntegralBatchRecord() {
		return mbrIntegralBatchRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMbrIntegralBatchRecord(Long mbrIntegralBatchRecord) {
		this.mbrIntegralBatchRecord = mbrIntegralBatchRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getBatchNo() {
		return batchNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setBatchNo(String batchNo) {
		this.batchNo = batchNo == null ? null : batchNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberName() {
		return memberName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberName(String memberName) {
		this.memberName = memberName == null ? null : memberName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberPhone() {
		return memberPhone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberPhone(String memberPhone) {
		this.memberPhone = memberPhone == null ? null : memberPhone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getErpId() {
		return erpId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setErpId(String erpId) {
		this.erpId = erpId == null ? null : erpId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeType() {
		return changeType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeType(Integer changeType) {
		this.changeType = changeType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getBusinessType() {
		return businessType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setBusinessType(Integer businessType) {
		this.businessType = businessType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Date getChangeTime() {
		return changeTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeTime(Date changeTime) {
		this.changeTime = changeTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeIntegral() {
		return changeIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeIntegral(Integer changeIntegral) {
		this.changeIntegral = changeIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getCountIntegral() {
		return countIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCountIntegral(Integer countIntegral) {
		this.countIntegral = countIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeStatus() {
		return changeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeStatus(Integer changeStatus) {
		this.changeStatus = changeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getReason() {
		return reason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setReason(String reason) {
		this.reason = reason == null ? null : reason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}

==> members-facade-20250930-20250909.101021-1-sources.jar: com/bizvane/members/facade/models/po/MbrIntegralBatchRecordPO.java <==
package com.bizvane.members.facade.models.po;

import com.bizvane.members.facade.utils.EncryptCardNo;
import com.bizvane.members.facade.utils.EncryptPhone;

import java.io.Serializable;
import java.util.Date;

@EncryptPhone
public class MbrIntegralBatchRecordPO implements Serializable {

	/**
	 * 只读. 批量调整积分记录表pk. mbr_integral_batch_record
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批量调整积分记录表pk", name = "mbrIntegralBatchRecord", required = false, example = "")
	private Long mbrIntegralBatchRecord;
	/**
	 * 只读. 公司id. sys_company_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. sys_brand_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
	private Long sysBrandId;
	/**
	 * 只读. 批次号. batch_no
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "批次号", name = "batchNo", required = false, example = "")
	private String batchNo;
	/**
	 * 只读. 会员名称. member_name
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员名称", name = "memberName", required = false, example = "")
	@EncryptCardNo
	private String memberName;
	/**
	 * 只读. 会员手机号. member_phone
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员手机号", name = "memberPhone", required = false, example = "")
	@EncryptPhone
	private String memberPhone;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 会员erpid. erp_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员erpid", name = "erpId", required = false, example = "")
	@EncryptCardNo
	private String erpId;
	/**
	 * 只读. 积分调整类型 1减少 2增加. change_type
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分调整类型 1减少 2增加", name = "changeType", required = false, example = "")
	private Integer changeType;
	/**
	 * 只读. 业务调整类型 4手动调整支出 5手动调整获取. business_type
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "业务调整类型 4手动调整支出 5手动调整获取", name = "businessType", required = false, example = "")
	private Integer businessType;
	/**
	 * 只读. 更改时间. change_time
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "更改时间", name = "changeTime", required = false, example = "")
	private Date changeTime;
	/**
	 * 只读. 变更积分. change_integral
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更积分", name = "changeIntegral", required = false, example = "")
	private Integer changeIntegral;
	/**
	 * 只读. 变更后积分. count_integral
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更后积分", name = "countIntegral", required = false, example = "")
	private Integer countIntegral;
	/**
	 * 只读. 积分变更状态 0处理中 1处理成功 2处理失败. change_status
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分变更状态 0处理中 1处理成功 2处理失败", name = "changeStatus", required = false, example = "")
	private Integer changeStatus;
	/**
	 * 只读. 积分调整结果. reason
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "积分调整结果", name = "reason", required = false, example = "")
	private String reason;
	/**
	 * 只读. 操作人id. create_user_id
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 操作人名称. create_user_name
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 操作日期. create_date
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 备注. remark
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 1有效 0无效. valid
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	@io.swagger.annotations.ApiModelProperty(value = "1有效 0无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getMbrIntegralBatchRecord() {
		return mbrIntegralBatchRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMbrIntegralBatchRecord(Long mbrIntegralBatchRecord) {
		this.mbrIntegralBatchRecord = mbrIntegralBatchRecord;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getSysBrandId() {
		return sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getBatchNo() {
		return batchNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setBatchNo(String batchNo) {
		this.batchNo = batchNo == null ? null : batchNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberName() {
		return memberName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberName(String memberName) {
		this.memberName = memberName == null ? null : memberName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberPhone() {
		return memberPhone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberPhone(String memberPhone) {
		this.memberPhone = memberPhone == null ? null : memberPhone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getErpId() {
		return erpId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setErpId(String erpId) {
		this.erpId = erpId == null ? null : erpId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeType() {
		return changeType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeType(Integer changeType) {
		this.changeType = changeType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getBusinessType() {
		return businessType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setBusinessType(Integer businessType) {
		this.businessType = businessType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Date getChangeTime() {
		return changeTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeTime(Date changeTime) {
		this.changeTime = changeTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeIntegral() {
		return changeIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeIntegral(Integer changeIntegral) {
		this.changeIntegral = changeIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getCountIntegral() {
		return countIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCountIntegral(Integer countIntegral) {
		this.countIntegral = countIntegral;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getChangeStatus() {
		return changeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setChangeStatus(Integer changeStatus) {
		this.changeStatus = changeStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getReason() {
		return reason;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setReason(String reason) {
		this.reason = reason == null ? null : reason.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2020-06-22 16:39:59
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}
